package task07;

/**
 * A filter that stems words using a Snowball-generated stemmer.
 * 
 * Available stemmers are listed in {@link org.tartarus.snowball.ext}.
 * <p>
 * <b>NOTE</b>: SnowballFilter expects lowercased text.
 * <ul>
 * <li>For the Turkish language, see {@link TurkishLowerCaseFilter}.
 * <li>For other languages, see {@link LowerCaseFilter}.
 * </ul>
 * </p>
 */
public final class Task07 {

	private SnowballProgram stemmer;

	public Task07(TokenStream input, SnowballProgram stemmer) {
		this.stemmer = stemmer;
	}

	/**
	 * TODO #07 (apache-lucene-3.6.1)
	 * <p>
	 * Construct the named stemming filter.
	 * 
	 * Available stemmers are listed in {@link org.tartarus.snowball.ext}. The
	 * name of a stemmer is the part of the class name before "Stemmer", e.g.,
	 * the stemmer in {@link org.tartarus.snowball.ext.EnglishStemmer} is named
	 * "English".
	 * 
	 * @param in
	 *            the input tokens to stem
	 * @param name
	 *            the name of a stemmer
	 */
	public Task07(TokenStream in, String name) {
		try {
			Class<?> stemClass = Class.forName("org.tartarus.snowball.ext."
					+ name + "Stemmer");
			stemmer = (SnowballProgram) stemClass.newInstance();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public SnowballProgram getStemmer() {
		return stemmer;
	}
}